==> dl.php?src=linea21_1_6.zip: linea21/templates/public/2013/index.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage public
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
 <!DOCTYPE html>
<!--[if lt IE 7 ]><html class="ie ie6" lang="<?php echo U_L; ?>"> <![endif]-->
<!--[if IE 7 ]><html class="ie ie7" lang="<?php echo U_L; ?>"> <![endif]-->
<!--[if IE 8 ]><html class="ie ie8" lang="<?php echo U_L; ?>"> <![endif]-->
<!--[if (gte IE 9)|!(IE)]><!--><html lang="<?php echo U_L; ?>"> <!--<![endif]-->
<?php distInclude(THEME_PUBLIC_PATH.'header.php', THEME_PUBLIC_DIST); ?>
<body>
<?php culture::getInstance()->renderSwitcher(); ?>
<header>
  <img src="<?php echo THEME_PUBLIC_PATH; ?>images/logo.png" alt="<?php echo (SITE_NAME); ?>" />
  <h1><?php echo (SITE_NAME); ?></h1>
</header><!-- End Header -->

<nav id="menu">
  <?php echo DisplayMenu(); ?>
</nav> <!-- End Menu -->

<section>
<div id="content" class="section_<?php echo ActiveItemKey($GLOBALS['activeitem']); ?> alias_<?php echo ActiveItemAlias($GLOBALS['activeitem']);?> <?php echo getItemId(); ?>">
  <div id="main-container">##BREADCRUMB##
  <div id="main"><!-- Begin Page -->
  	<div id="printer">
  		<a href="javascript:self.print();" class="button" title="<?php echo _t('divers','print'); ?>"><span><?php echo _t('divers','print'); ?></span></a>
    </div>
    	<?php DisplayTemplate(); ?>
  </div> <!-- End Page -->
  <hr class="spacer" />
  </div> <!-- End Main -->

  <aside>
    <?php distInclude(THEME_PUBLIC_PATH.'sidebar.php', THEME_PUBLIC_DIST); ?>
  </aside><!-- End Sidebar -->
</div> <!-- End Content -->
</section>

<!-- Footer -->

<footer><?php displayDefaultFooter(); ?>
  <p>Linea21 (v <?php echo LINEA_VERSION; ?>), <?php printf(_t('divers','licence') ,'<a href="http://opensource.org/licenses/gpl-3.0.html" title="GNU GPL v3" class="out">GNU GPL v3</a>'); ?></p>
  <?php if(isset($_SESSION['authenticated']) && !$l21auth->isSimpleUser())  { ?>
  	<a href="../admin/index.php" title="<?php echo _t('header','title');?>"><?php echo _t('header','title');?></a>
  <?php  } ?>
</footer>
<!-- End Footer -->
<?php AddDynamicFooter(); ?>
<?php if(isset($Dbg)) $Dbg->display(); ?>
</body>
</html>

==> dl.php?src=linea21_1_7.zip: linea21/templates/public/2013/index.php <==
<?php
/**
 * @package linea21.templates
 * @subpackage public
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

// uncomment to allow access only to authentified users
// if(!$l21auth->isAuthenticated() && ActiveItemKey($_REQUEST['rub'])!='user-prefs') {
// 	header("Location: ../public/index.php?rub=".$GLOBALS['links'][U_L]['user-prefs']['linkvalue']);
// 	exit;
// }
include_once('../class/class.page.php');
include_once(override('../page/display.php'));
include_once(override('../page/'.SQL.'.inc.php'));
?>
 <!DOCTYPE html>
<!--[if lt IE 7 ]><html class="ie ie6" lang="<?php echo U_L; ?>"> <![endif]-->
<!--[if IE 7 ]><html class="ie ie7" lang="<?php echo U_L; ?>"> <![endif]-->
<!--[if IE 8 ]><html class="ie ie8" lang="<?php echo U_L; ?>"> <![endif]-->
<!--[if (gte IE 9)|!(IE)]><!--><html lang="<?php echo U_L; ?>"> <!--<![endif]-->
<?php distInclude(THEME_PUBLIC_PATH.'header.php', THEME_PUBLIC_DIST); ?>
<body>
<?php culture::getInstance()->renderSwitcher(); ?>
<header>
  <img src="<?php echo THEME_PUBLIC_PATH; ?>images/logo.png" alt="<?php echo (SITE_NAME); ?>" />
  <h1><?php echo (SITE_NAME); ?></h1>
</header><!-- End Header -->

<nav id="menu">
  <?php echo DisplayMenu(); ?>
</nav> <!-- End Menu -->

<section>
<div id="content" class="section_<?php echo ActiveItemKey($GLOBALS['activeitem']); ?> alias_<?php echo ActiveItemAlias($GLOBALS['activeitem']);?> <?php echo getItemId(); ?>">
  <div id="main-container">##BREADCRUMB##
  <div id="main"><!-- Begin Page -->
  	<div id="printer">
  		<a href="javascript:self.print();" class="button" title="<?php echo _t('divers','print'); ?>"><span><?php echo _t('divers','print'); ?></span></a>
    </div>
    	<?php DisplayTemplate(); ?>
  </div> <!-- End Page -->
  <hr class="spacer" />
  </div> <!-- End Main -->

  <aside>
    <?php distInclude(THEME_PUBLIC_PATH.'sidebar.php', THEME_PUBLIC_DIST); ?>
  </aside><!-- End Sidebar -->
</div> <!-- End Content -->
</section>

<!-- Footer -->

<footer><?php displayDefaultFooter(); ?>
  <p>Linea21 (v <?php echo LINEA_VERSION; ?>), <?php printf(_t('divers','licence') ,'<a href="http://opensource.org/licenses/gpl-3.0.html" title="GNU GPL v3" class="out">GNU GPL v3</a>'); ?></p>
  <?php if(isset($_SESSION['authenticated']) && !$l21auth->isSimpleUser())  { ?>
  	<a href="../admin/index.php" title="<?php echo _t('header','title');?>"><?php echo _t('header','title');?></a>
  <?php  } ?>
</footer>
<!-- End Footer -->
<?php AddDynamicFooter(); ?>
<?php if(isset($Dbg)) $Dbg->display(); ?>
</body>
</html>
